#ifndef DEFINES_H
#define DEFINES_H

#include <QString>
#include <QList>
#include <QtGlobal>

#define VERSION "LibreMediaServerAudio 0.2.0 Antigona Release"
#define COPYRIGHT "(C) 2014-2024 Santi Norena lms@criptomart.net"
#define LICENSE "GPL 3 License. See LICENSE.txt and credits.txt for details"
#define DEFAULT_FILE "lms-audio.xlm"
#define MAX_LAYERS 16
#define UI_REFRESH_TIME 200

// struct where save the DMX settings for each layer
struct dmxSetting {
    int address;
    quint8 universe;
    bool updated;
    int layer;
};

// Media Information for MELIn packages. v1.0
struct MediaFile {
    quint8 Number; // 0-based contiguous index of the media.
    QString MediaName;// Media name.
    quint32 MediaLength;// Media length (in frames).
};

// Media Library for ELin packages v1.0
struct MediaFolder {
    quint8 m_Id; // Library id.
    QString m_Name;// Library name.
    quint8 m_ElementCount;// Number of elements in the library.
    QList<MediaFile> m_MediaInformation; // Pointer to the Medias Information List of this Library
};

enum Status
{
    Stopped,
    Paused,
    PlayingOnce,
    PlayingLoop,
};

static const char* StatusStr[] =
{
    "Stop",
    "Pause",
    "Playing One",
    "Playing Loop",
    NULL
};

enum Slider
{
    Volume,
    Pan,
    Pitch,
};

#endif // DEFINES_H

